<?php

namespace Kylin\Auth\Exceptions;

use Kylin\Auth\Enums\AuthErrorCode;
use Kylin\Core\Exceptions\BusinessException;

/**
 * 认证异常
 *
 * 认证相关的业务异常，携带 AuthErrorCode 错误码。
 */
class AuthException extends BusinessException
{
    public function __construct(
        AuthErrorCode $errorCode,
        ?string $message = null,
    ) {
        parent::__construct($errorCode, $message);
    }
}
