<?php

namespace Kylin\Auth\Facades;

use Illuminate\Support\Facades\Facade;

/**
 * 认证门面
 *
 * 提供认证服务的静态访问入口。
 */
class KylinAuth extends Facade
{
    protected static function getFacadeAccessor(): string
    {
        return 'kylin-auth';
    }
}
